==> fioRa_0.3.4.zip: fioRa/NEWS.md <==
# v0.3.4 by jan.lisec@bam.de

* App GUI improved (better selection of individual results)
* default python environment switched to conda

# v0.3.3 by jan.lisec@bam.de

* `run_script` gains an argument `fmt` which allows to export results in a data frame
* additional test_that tests implemented to prepare for CRAN release

# v0.3.2 by jan.lisec@bam.de

* included `test_data` object in the package
* modified the `run_script()` function to accept a data frame with multiple 
  lines as input

# v0.3.1 by jan.lisec@bam.de

* updated to **fiora** model `1.0.1`
* increased resolution of spectra plots in app
* allowed to use different fiora models (from different python environments)
  in function *run_script()*

# v0.2.5 by jan.lisec@bam.de

* neutral losses shown in spectra plots
* sum formulas corrected for H number using the adduct annotation of **fiora**
* sum formulas scaled to comparable size in spectra plots

# v0.2.4 by jan.lisec@bam.de

* *predict()* renamed to *run_script()*
* detection of python and script path platform specific
* script evaluation platform specific

# v0.2.3 by jan.lisec@bam.de

* script path hardcoded; reticulate not used

# v0.2.2 by jan.lisec@bam.de

* moved reticulate to Suggest in Description if python installation and script is found

# v0.2.1 by jan.lisec@bam.de

* modified fiora installation using a conda environment

# v0.1.1 by jan.lisec@bam.de

* Shiny App working on shinyapps.io
* local function `predict` is working
* spectrum plot is showing formulas and molecular structures
* several testthat tests implemented
* ReadMe and News.md set up

# v0.0.0.9000 by jan.lisec@bam.de

* initial GitHub submission

==> fioRa_0.3.7.zip: fioRa/NEWS.md <==
# v0.3.7 by jan.lisec@bam.de (2026-01-22)

* several improvements regarding the shiny app
* plot output for spectra improved a lot, i.e. isomeric peaks are combined now,
  neutral losses are computed between fragments in addition to the precursor,
  annotation can be omitted for minor peaks, all sum formulas are depicted using
  subscript for numbers to improve readability, font size was increased
* Help page received some input (very basic, for first time users)

# v0.3.6 by jan.lisec@bam.de

* `read_fiora()` now exported function
* result can be converted to object of class `Spectra` (see Spectra package)
* result can be written to a file path only (no console output)
* parallel conda environments for different FIORA versions are now supported by
  using the `conda_name` parameter in `install_fiora()`

# v0.3.5 by jan.lisec@bam.de

* CRAN badge
* modified module of selectInputWithButtons to be better tested

# v0.3.4 by jan.lisec@bam.de

* App GUI improved (better selection of individual results)
* default python environment switched to conda

# v0.3.3 by jan.lisec@bam.de

* `run_script` gains an argument `fmt` which allows to export results in a data frame
* additional test_that tests implemented to prepare for CRAN release

# v0.3.2 by jan.lisec@bam.de

* included `test_data` object in the package
* modified the `run_script()` function to accept a data frame with multiple 
  lines as input

# v0.3.1 by jan.lisec@bam.de

* updated to **fiora** model `1.0.1`
* increased resolution of spectra plots in app
* allowed to use different fiora models (from different python environments)
  in function *run_script()*

# v0.2.5 by jan.lisec@bam.de

* neutral losses shown in spectra plots
* sum formulas corrected for H number using the adduct annotation of **fiora**
* sum formulas scaled to comparable size in spectra plots

# v0.2.4 by jan.lisec@bam.de

* *predict()* renamed to *run_script()*
* detection of python and script path platform specific
* script evaluation platform specific

# v0.2.3 by jan.lisec@bam.de

* script path hardcoded; reticulate not used

# v0.2.2 by jan.lisec@bam.de

* moved reticulate to Suggest in Description if python installation and script is found

# v0.2.1 by jan.lisec@bam.de

* modified fiora installation using a conda environment

# v0.1.1 by jan.lisec@bam.de

* Shiny App working on shinyapps.io
* local function `predict` is working
* spectrum plot is showing formulas and molecular structures
* several testthat tests implemented
* ReadMe and News.md set up

# v0.0.0.9000 by jan.lisec@bam.de

* initial GitHub submission
